==> openshift-model-6.6.1-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ResourceQuotaSpec;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterResourceQuotaSpecFluent<A extends ClusterResourceQuotaSpecFluent<A>> extends Fluent<A>{
  public ResourceQuotaSpec getQuota();
  public A withQuota(ResourceQuotaSpec quota);
  public Boolean hasQuota();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterResourceQuotaSelector getSelector();
  public ClusterResourceQuotaSelector buildSelector();
  public A withSelector(ClusterResourceQuotaSelector selector);
  public Boolean hasSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> withNewSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> withNewSelectorLike(ClusterResourceQuotaSelector item);
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> editSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> editOrNewSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> editOrNewSelectorLike(ClusterResourceQuotaSelector item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SelectorNested<N> extends Nested<N>,ClusterResourceQuotaSelectorFluent<ClusterResourceQuotaSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ResourceQuotaSpec;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterResourceQuotaSpecFluent<A extends ClusterResourceQuotaSpecFluent<A>> extends Fluent<A>{
  public ResourceQuotaSpec getQuota();
  public A withQuota(ResourceQuotaSpec quota);
  public Boolean hasQuota();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterResourceQuotaSelector getSelector();
  public ClusterResourceQuotaSelector buildSelector();
  public A withSelector(ClusterResourceQuotaSelector selector);
  public Boolean hasSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> withNewSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> withNewSelectorLike(ClusterResourceQuotaSelector item);
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> editSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> editOrNewSelector();
  public ClusterResourceQuotaSpecFluent.SelectorNested<A> editOrNewSelectorLike(ClusterResourceQuotaSelector item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SelectorNested<N> extends Nested<N>,ClusterResourceQuotaSelectorFluent<ClusterResourceQuotaSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
